!!! info "Overview API"
    The Overview API provides information about the availability of the CANFAR Science Platform.

::: canfar.overview.Overview
    handler: python
    selection:
      members:
        - availability
    rendering:
      members_order: source
      show_root_heading: true
      show_source: true
      heading_level: 1
